# PrivateStreetSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**private_street_reference_number** | **str** |  | 
**proposed_start_date** | **datetime** |  | 
**proposed_start_time** | **datetime** |  | [optional] 
**proposed_end_date** | **datetime** |  | 
**proposed_end_time** | **datetime** |  | [optional] 
**private_street_status** | [**PrivateStreetStatusResponse**](PrivateStreetStatusResponse.md) |  | 
**private_street_status_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

